@@ -49,16 +49,25 @@
 #define BARCODE_TYPE_QRCODE   3
 #define BARCODE_TYPE_PDF417   4
 
-#define WIDTH  320
+#define WIDTH   400
 #define HEIGHT  240
 
-#define N900_WIDTH  640
-#define N900_HEIGHT  480
+#define N900_WIDTH  400
+#define N900_HEIGHT 240
 
-#define NO_OF_COLUMNS   4
+#define PAINTGL_INTERVAL_LOW    500
+#define PAINTGL_INTERVAL_HIGH   10
+
+#define NO_OF_COLUMNS       4
+#define SETTINGS_VERSION    2
 
 #define SCAN_HISTORY_LENGTH 10
 
 #define TYPE_DMTX "dmtx"
 
+// DBus addresses
+#define DBUS_SHUTTER_STATE "/org/freedesktop/Hal/devices/platform_cam_shutter"
+#define DBUS_FOCUS_BUTTON "/org/freedesktop/Hal/devices/platform_cam_focus"
+#define DBUS_RELEASE_BUTTON "/org/freedesktop/Hal/devices/platform_cam_launch"
+
 #endif // COMMON_H
