@@ -58,6 +58,7 @@ VideoWidget::VideoWidget(MaemoBarcodeWindow *parent) : QGLWidget(parent) {
     VideoWidget(parent, newdecoder);
 }
 VideoWidget::VideoWidget(MaemoBarcodeWindow *parent, BarcodeDetector *decoder) : QGLWidget(parent) {
+    qDebug() << "VideoWidget::VideoWidget(): Called";
     pipeline = NULL;
     this->parent = parent;
     keepRunning = true;
@@ -78,8 +79,11 @@ VideoWidget::VideoWidget(MaemoBarcodeWindow *parent, BarcodeDetector *decoder) :
     pipelineReady = false;
     focusing = false;
     videoWidget_callback = this; // set the global pointer to this object
+    qDebug() << "VideoWidget::VideoWidget(): Getting device type";
     getDeviceType(); // work out which device we are so we can specify what type of pipeline to setup
+    qDebug() << "VideoWidget::VideoWidget(): Initializing pipeline";
     initPipeline(); // create the GStreamer pipeline
+    qDebug() << "VideoWidget::VideoWidget(): Pipeline initialized";
     this->decoder = decoder; // create a new decoder object
 
     continuousFocusInterval = 3000;
@@ -87,6 +91,7 @@ VideoWidget::VideoWidget(MaemoBarcodeWindow *parent, BarcodeDetector *decoder) :
     connect(refocusTimer, SIGNAL(timeout()), this, SLOT(refocus()));
     refocusTimer->setInterval(continuousFocusInterval);
 
+    qDebug() << "VideoWidget::VideoWidget(): Setting up images";
     // set up GUI stuff
     imgExit = QImage(":/images/gui/cross.png");
     imgExit = imgExit.scaledToWidth(48, Qt::SmoothTransformation);
@@ -99,6 +104,7 @@ VideoWidget::VideoWidget(MaemoBarcodeWindow *parent, BarcodeDetector *decoder) :
     imgSettings = QImage(":/images/gui/settings.png");
     imgSettings = imgSettings.scaledToWidth(48, Qt::SmoothTransformation);
 
+    qDebug() << "VideoWidget::VideoWidget(): Setting up frame counts";
     // timer, should be set last, just in case
     frames = 0;
     frametime.start();
@@ -106,6 +112,7 @@ VideoWidget::VideoWidget(MaemoBarcodeWindow *parent, BarcodeDetector *decoder) :
     QObject::connect(timerOpenGL, SIGNAL(timeout()), this, SLOT(updateGL()));
     timerOpenGL->setInterval(PAINTGL_INTERVAL_HIGH); //update the window every x milliseconds
     timerOpenGL->start();
+    qDebug() << "VideoWidget::VideoWidget(): Finished";
 }
 
 VideoWidget::~VideoWidget() {
@@ -440,25 +447,30 @@ bool VideoWidget::initPipeline() {
     GstCaps *caps;
     GstBus *bus;
 
-
+    qDebug() << "VideoWidget::initPipeline(): initializing gstreamer";
     /* Initialize Gstreamer */
     gst_init (0, 0);
 
     /* Create pipeline and attach a callback to it's
      * message bus */
+    qDebug() << "VideoWidget::initPipeline(): creating new pipeline";
     pipeline = gst_pipeline_new ("test-camera");
     if(!pipeline)
         qCritical("VideoWidget::initPipeline(): pipeline failed to init");
 
+    qDebug() << "VideoWidget::initPipeline(): getting bus";
     bus = gst_pipeline_get_bus (GST_PIPELINE (pipeline));
     // for the xvimagesink stuff, from here: http://gstreamer.freedesktop.org/data/doc/gstreamer/head/gst-plugins-base-libs/html/gst-plugins-base-libs-gstxoverlay.html#gst-x-overlay-set-xwindow-id
-
+    qDebug() << "VideoWidget::initPipeline(): adding watch";
     gst_bus_add_watch (bus, (GstBusFunc) VideoWidget::busCallback_callback, NULL);
+    qDebug() << "VideoWidget::initPipeline(): unrefing bus";
     gst_object_unref (GST_OBJECT (bus));
 
     /* Camera video stream comes from a Video4Linux driver */
+    qDebug() << "VideoWidget::initPipeline(): making factory";
     if (deviceType==DEVICE_N900){
         camera_src = gst_element_factory_make("v4l2camsrc", "camera_src"); // gst_photography_set_autofocus(GST_PHOTOGRAPHY(cameraSrc), TRUE)
+        qDebug() << "VideoWidget::initPipeline(): setting object";
         g_object_set(G_OBJECT(camera_src), "driver-name", "omap3cam", NULL); // thanks BBNS_ @ maemo irc aka Yun-Ta Tsai
     } else if (deviceType==DEVICE_N810) {
         camera_src = gst_element_factory_make("gconfv4l2src", "camera_src");
@@ -469,20 +481,23 @@ bool VideoWidget::initPipeline() {
     if(!camera_src)
         qCritical("VideoWidget::initPipeline(): camera_src failed to init");
     else
-        qDebug("VideoWidget::initPipeline(): camera_src is now loaded");
+        qDebug() << "VideoWidget::initPipeline(): camera_src is now loaded";
 
+    qDebug() << "VideoWidget::initPipeline(): Setting file source";
     file_src = gst_element_factory_make("filesrc", "file_src");
     //useFilesrc("/usr/share/icons/hicolor/14x14/hildon/general_alarm_on.png"); // dummy file to do a quickfix
+    qDebug() << "VideoWidget::initPipeline(): Setting input selector";
     input_selector = gst_element_factory_make("input-selector", "input_selector");
     //    g_object_set(G_OBJECT(input_selector), "n-pads", 2, NULL); // set 2 input pads
 
     /* Colorspace filter is needed to make sure that sinks understands
      * the stream coming from the camera */
+    qDebug() << "VideoWidget::initPipeline(): Creating csp_filter";
     csp_filter = gst_element_factory_make ("ffmpegcolorspace", "csp_filter");
     if(!csp_filter)
         qCritical("VideoWidget::initPipeline(): csp_filter failed to init");
     else
-        qDebug("VideoWidget::initPipeline(): csp_filter is now loaded");
+        qDebug() << "VideoWidget::initPipeline(): csp_filter is now loaded";
     /* Filter to convert stream to use format that the gdkpixbuf library can use */
     image_filter = gst_element_factory_make("ffmpegcolorspace", "image_filter");
 
@@ -492,14 +507,6 @@ bool VideoWidget::initPipeline() {
     g_object_set (G_OBJECT (video_crop), "right", frame_width / 2, NULL);
     g_object_set (G_OBJECT (video_crop), "top", frame_height / 2, NULL);
 
-
-    /* Tee that copies the stream to multiple outputs */
-    //    tee = gst_element_factory_make ("tee", "tee");
-    //    if(!tee)
-    //        qCritical("VideoWidget::initPipeline(): tee failed to init");
-    //    else
-    //        qDebug("VideoWidget::initPipeline(): tee is now loaded");
-
     /* Queue creates new thread for the stream */
     screen_queue = gst_element_factory_make ("queue", "screen_queue");
     if(!screen_queue)
@@ -519,21 +526,9 @@ bool VideoWidget::initPipeline() {
     if(!pipeline)
         qCritical("VideoWidget::initPipeline(): pipeline failed to init");
 
-    /* Filter to convert stream to use format that the gdkpixbuf library
-     * can use */
-    //image_filter = gst_element_factory_make ("ffmpegcolorspace", "image_filter");
-    //if(!image_filter)
-    //    qDebug("image_filter failed to init");
-
-    /* A dummy sink for the image stream. Goes to bitheaven */
-    //    image_sink = gst_element_factory_make ("fakesink", "image_sink");
-    //    if(!image_sink)
-    //        qCritical("VideoWidget::initPipeline(): image_sink failed to init");
-    //    g_object_set (G_OBJECT (image_sink), "sync", FALSE, NULL);
-
     /* Check that elements are correctly initialized */
     if (!(pipeline && camera_src && screen_sink && csp_filter && screen_queue && image_queue /*&& image_sink*/ && video_crop && image_filter/*&& file_src && input_selector*/)) {
-        g_critical ("VideoWidget::initPipeline(): Couldn't create pipeline elements");
+        qCritical ("VideoWidget::initPipeline(): Couldn't create pipeline elements");
         return FALSE;
     }
 
@@ -547,13 +542,17 @@ bool VideoWidget::initPipeline() {
 
     /* Specify what kind of video is wanted from the camera */
     if (deviceType==DEVICE_N900){
-        qDebug("Using N900 caps");
-        caps = gst_caps_from_string("video/x-raw-yuv,format=(fourcc)UYVY,width=" + QString::number(frame_width * 2).toAscii() + ",height=" + QString::number(frame_height * 2).toAscii()); //,framerate=[1/10,10/1]"); //width=320,height=240
-        //        caps = gst_caps_new_simple("video/x-raw-yuv",
-        //            "width", G_TYPE_INT, 320,
-        //            "height", G_TYPE_INT, 240,
-        //            "framerate", GST_TYPE_FRACTION, 323, 25,
-        //            NULL);
+        qDebug() << "VideoWidget::initPipeline(): Using N900 caps";
+        caps = gst_caps_new_simple("video/x-raw-yuv",
+                        "format",  GST_TYPE_FOURCC, GST_MAKE_FOURCC ('U', 'Y', 'V', 'Y'),
+                        "width", G_TYPE_INT, frame_width * 2,
+                        "height", G_TYPE_INT, frame_height * 2,
+                        "bpp", G_TYPE_INT, 24,
+                        "framerate", GST_TYPE_FRACTION, 25, 1,
+                        NULL);
+
+        qDebug() << "VideoWidget::initPipeline(): Used N900 caps";
+
     }else{
         qDebug("Using N8x0 caps");
         caps = gst_caps_new_simple ("video/x-raw-yuv",
@@ -563,78 +562,40 @@ bool VideoWidget::initPipeline() {
     }
     /* Link the camera source and colorspace filter using capabilities
      * specified */
+    qDebug() << "VideoWidget::initPipeline(): Linking filtered";
     if (!gst_element_link_filtered (camera_src, csp_filter, caps)) {
         qCritical() << "VideoWidget::initPipeline(): Failed to link caps!";
         return FALSE;
     }
 
+    qDebug() << "VideoWidget::initPipeline(): Unref caps";
     gst_caps_unref (caps);
 
-    caps = gst_caps_from_string("video/x-raw-rgb,width=" +
-                                QString::number(frame_width).toAscii() +
-                                ",height=" + QString::number(frame_height).toAscii());//framerate=[1/30,30/1]
-    if(!gst_element_link_many(csp_filter, video_crop, /*tee,*/ screen_queue, image_filter, NULL)) {
+    qDebug() << "VideoWidget::initPipeline(): Using rgb caps";
+    caps = gst_caps_new_simple("video/x-raw-rgb",
+                    "width", G_TYPE_INT, frame_width,
+                    "height", G_TYPE_INT, frame_height,
+                    "bpp", G_TYPE_INT, 24,
+                    NULL);
+
+    qDebug() << "VideoWidget::initPipeline(): Linking again";
+    if(!gst_element_link_many(csp_filter, video_crop, screen_queue, image_filter, NULL)) {
         qCritical() << "VideoWidget::initPipeline(): Failed to link many 1";
         return FALSE;
     }
+    qDebug() << "VideoWidget::initPipeline(): Linking another filtered";
     if(!gst_element_link_filtered(image_filter, screen_sink, caps)) {
         qCritical() << "VideoWidget::initPipeline(): Failed to link filtered";
         return FALSE;
     }
+    qDebug() << "VideoWidget::initPipeline(): Unrefing caps";
     gst_caps_unref(caps);
-    //    qDebug() << "Making caps";
-    //    caps = gst_caps_from_string("video/x-raw-rgb,width=320,height=240");//framerate=[1/30,30/1]
-    //    qDebug() << "Linking many";
-    //    if(!gst_element_link_many(video_crop, tee, screen_queue, screen_sink,csp_filter,image_filter, NULL)) return FALSE;
-    //    qDebug() << "Linking filter";
-    //    if(!gst_element_link_filtered(image_filter, image_sink,caps)) return FALSE;
-
-    //    qDebug() << "Unref caps";
-    //    gst_caps_unref(caps);
-    //    if (!gst_element_link_many (csp_filter, video_crop, tee, screen_queue, screen_sink, NULL))
-    //        return FALSE;
-
-    /* Connect Colorspace Filter -> Tee -> Screen Queue -> Screen Sink
-     * This finalizes the initialization of the screen-part of the pipeline */
-    //    if (!gst_element_link(csp_filter, video_crop))
-    //        return FALSE;
-
-
-    // link up the input_selector here
-    //    gst_element_link_pads (video_crop, "src", input_selector, "sink");
-    //    gst_element_link_pads (file_src, "src", input_selector, "sink");
-
-    //g_object_set(G_OBJECT(input_selector), "active-pad", gst_element_get_pad(video_crop, "src"), NULL);
-
-
-    //caps = gst_caps_new_simple ("video/x-raw-yuv", "width", G_TYPE_INT, WIDTH, "height", G_TYPE_INT, HEIGHT, NULL);
-
-    /* Link the image-branch of the pipeline. The pipeline is
-     * ready after this */
-    //    if (!gst_element_link_many (tee, image_queue, /*image_sink,*/ NULL)) {
-    //        qCritical() << "Failed to link many!";
-    //        return FALSE;
-    //    }
-    //if (!gst_element_link_filtered (image_filter, image_sink, caps))
-    //    return FALSE;
-
-    //gst_caps_unref (caps);
-
-    /* As soon as screen is exposed, window ID will be advised to the sink */
-    //g_signal_connect (screen, "expose-event", G_CALLBACK (expose_cb), screen_sink);
 
+    qDebug() << "VideoWidget::initPipeline(): Ask for emitted signals";
     g_object_set (G_OBJECT (screen_sink), "emit-signals", TRUE, NULL);
+    qDebug() << "VideoWidget::initPipeline(): Creating screen sink";
     g_signal_connect (screen_sink, "new-buffer", G_CALLBACK (new_buffer_added_callback), NULL);
 
-    //    buffer_cb_id = g_signal_connect (G_OBJECT (image_sink), "handoff", G_CALLBACK (bufferProbeCallback_callback), NULL);
-
-    //    sink = gst_element_factory_make("xvimagesink", "sink");
-    //    gst_element_set_state(sink, GST_STATE_READY);
-    //
-    //    QApplication::syncX();
-    //    gst_x_overlay_set_xwindow_id(GST_X_OVERLAY(sink), videoWidget->window()->winId());
-    //    data = screen_sink;
-
     qDebug() << "Pipeline initialized with success!";
     return true;
 }
