@@ -33,12 +33,14 @@
 #ifndef VIDEOWIDGET_H
 #define VIDEOWIDGET_H
 // qt includes
-#include <QWidget>
+#include <QtOpenGL>
+#include <QTime>
 // gstreamer includes
 #include <gst/gst.h>
 #include <gst/gstbin.h>
 #include <gst/interfaces/xoverlay.h>
 #include <gst/interfaces/photography.h>
+#include <gst/app/gstappsink.h>
 // other includes
 #include <stdio.h>
 #include <zbar.h>
@@ -47,23 +49,32 @@
 
 class BarcodeDetector;
 class DBusConnection;
+class MaemoBarcodeWindow;
 using namespace zbar;
 
-class VideoWidget : public QWidget
+class VideoWidget : public QGLWidget
 {
     Q_OBJECT
 public:
-    VideoWidget(QWidget *parent);
-    VideoWidget(QWidget *parent, BarcodeDetector *decoder);
+    VideoWidget(MaemoBarcodeWindow *parent);
+    VideoWidget(MaemoBarcodeWindow *parent, BarcodeDetector *decoder);
     ~VideoWidget();
-    void setData(GstElement *data);
-    void start();
-    void stop();
+    void start(bool startEvenIfNotYetStarted = false);
+    void stop(bool stopCompletely = false);
     bool isFocusing();
     void useVideosrc();
     void useFilesrc(QString filename);
     void setContinuousFocusTime(int milliseconds);
+    bool isPipelineReady();
 
+    // openGL functions
+    static int buffer_width;
+    static int buffer_height;
+    bool cold_start;
+    void refreshTexture();
+
+    // refocus
+    QTimer *refocusTimer;
 
 public slots:
     void refocus();
@@ -73,21 +84,34 @@ signals:
     void focusingValueChanged(bool enabled);
     void doSaveBuffer();
 
+protected:
+    void resizeGL(int w, int h);
+    void paintGL();
+    void initializeGL();
+
 private:
     void setFocusing(bool enabled);
-    GstElement *data, *pipeline;
-    void paintEvent(QPaintEvent *);
-    GstBusSyncReply handleCreateWindow(GstBus * bus, GstMessage * message, GstPipeline * pipeline);
-    static GstBusSyncReply handleCreateWindow_callback(GstBus * bus, GstMessage * message, GstPipeline * pipeline);
+    bool keepRunning;
+    // openGL functions
+    void paintTexturedCube();
+    void paintQtLogo();
+    void refreshBuffer();
+
+    void newBufferAdded (GstAppSink *_appsink, gpointer user_data);
+    static void new_buffer_added_callback (GstAppSink *_appsink, gpointer user_data);
+
+    // Gst functions
     gboolean busCallback (GstBus * bus, GstMessage * message);
     static gboolean busCallback_callback (GstBus * bus, GstMessage * message);
-    gboolean bufferProbeCallback (GstElement *image_sink, GstBuffer *buffer, GstPad *pad);
-    static gboolean bufferProbeCallback_callback (GstElement *image_sink, GstBuffer *buffer, GstPad *pad);
+    gboolean bufferProbeCallback (char *data);
+//    static gboolean bufferProbeCallback_callback (GstElement *image_sink, GstBuffer *buffer, GstPad *pad);
     void destroyPipeline();
     bool initPipeline();
     void getDeviceType();
+
     bool pipelineReady;
     BarcodeDetector *decoder;
+    GstElement *pipeline;
 
     // added from appdata.h
     GstElement *camera_src;
@@ -110,9 +134,46 @@ private:
     zbar_image_t *image;
     bool focusing;
 
-    QTimer *refocusTimer;
+    // openGL painting
+    int frames;
+    QTime frametime;
+    QTimer *timerOpenGL;
+    GLuint m_uiTexture;
+    QGLShaderProgram *program2;
+//    GLuint program;
+    int vertexAttr;
+    int normalAttr;
+    int texCoordAttr;
+    int matrixUniform;
+    int textureUniform;
+    bool qtLogo;
+    bool m_showBubbles;
+    bool m_showBackground;
+    QTime time;
+    GstBuffer *gstBuffer;
+    bool buffer_ready;
+    GstAppSink *appsink;
+    bool appSinkScanning;
+
+
+    // GUI stuff
+    QImage imgExit;
+    QPoint imgExitPos;
+    QImage imgSave;
+    QPoint imgSavePos;
+    QImage imgTaskManager;
+    QPoint imgTaskManagerPos;
+    QImage imgRecent;
+    QPoint imgRecentPos;
+    QImage imgSettings;
+    QPoint imgSettingsPos;
     int continuousFocusInterval;
 
+    //
+    MaemoBarcodeWindow *parent;
+
+
+
 private slots:
     void mousePressEvent(QMouseEvent *event);
 };
